import { withPostGraphileContext, createPostGraphileSchema } from 'postgraphile';
import { graphql } from 'graphql';
import { print } from 'graphql/language/printer';
export const getSchema = async (pool, settings) => await createPostGraphileSchema(pool, settings.schema, settings);
export class GraphileQuery {
    pool;
    schema;
    settings;
    constructor({ schema, pool, settings }) {
        if (!schema)
            throw new Error('requires a schema');
        if (!pool)
            throw new Error('requires a pool');
        if (!settings)
            throw new Error('requires graphile settings');
        this.pool = pool;
        this.schema = schema;
        this.settings = settings;
    }
    async query({ req = {}, query, variables, role }) {
        const queryString = typeof query === 'string' ? query : print(query);
        const { pgSettings: pgSettingsGenerator } = this.settings;
        const pgSettings = role != null
            ? { role }
            : typeof pgSettingsGenerator === 'function'
                ? await pgSettingsGenerator(req)
                : pgSettingsGenerator;
        return await withPostGraphileContext({
            ...this.settings,
            pgPool: this.pool,
            pgSettings
        }, async (context) => {
            return await graphql({
                schema: this.schema,
                source: queryString,
                contextValue: context,
                variableValues: variables
            });
        });
    }
}
export class GraphileQuerySimple {
    pool;
    schema;
    constructor({ schema, pool }) {
        if (!schema)
            throw new Error('requires a schema');
        if (!pool)
            throw new Error('requires a pool');
        this.pool = pool;
        this.schema = schema;
    }
    async query(query, variables) {
        const queryString = typeof query === 'string' ? query : print(query);
        return await withPostGraphileContext({ pgPool: this.pool }, async (context) => {
            return await graphql({
                schema: this.schema,
                source: queryString,
                contextValue: context,
                variableValues: variables
            });
        });
    }
}
