"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GraphileQuerySimple = exports.GraphileQuery = exports.getSchema = void 0;
const postgraphile_1 = require("postgraphile");
const graphql_1 = require("graphql");
const printer_1 = require("graphql/language/printer");
const getSchema = async (pool, settings) => await (0, postgraphile_1.createPostGraphileSchema)(pool, settings.schema, settings);
exports.getSchema = getSchema;
class GraphileQuery {
    pool;
    schema;
    settings;
    constructor({ schema, pool, settings }) {
        if (!schema)
            throw new Error('requires a schema');
        if (!pool)
            throw new Error('requires a pool');
        if (!settings)
            throw new Error('requires graphile settings');
        this.pool = pool;
        this.schema = schema;
        this.settings = settings;
    }
    async query({ req = {}, query, variables, role }) {
        const queryString = typeof query === 'string' ? query : (0, printer_1.print)(query);
        const { pgSettings: pgSettingsGenerator } = this.settings;
        const pgSettings = role != null
            ? { role }
            : typeof pgSettingsGenerator === 'function'
                ? await pgSettingsGenerator(req)
                : pgSettingsGenerator;
        return await (0, postgraphile_1.withPostGraphileContext)({
            ...this.settings,
            pgPool: this.pool,
            pgSettings
        }, async (context) => {
            return await (0, graphql_1.graphql)({
                schema: this.schema,
                source: queryString,
                contextValue: context,
                variableValues: variables
            });
        });
    }
}
exports.GraphileQuery = GraphileQuery;
class GraphileQuerySimple {
    pool;
    schema;
    constructor({ schema, pool }) {
        if (!schema)
            throw new Error('requires a schema');
        if (!pool)
            throw new Error('requires a pool');
        this.pool = pool;
        this.schema = schema;
    }
    async query(query, variables) {
        const queryString = typeof query === 'string' ? query : (0, printer_1.print)(query);
        return await (0, postgraphile_1.withPostGraphileContext)({ pgPool: this.pool }, async (context) => {
            return await (0, graphql_1.graphql)({
                schema: this.schema,
                source: queryString,
                contextValue: context,
                variableValues: variables
            });
        });
    }
}
exports.GraphileQuerySimple = GraphileQuerySimple;
